
/**
 * @file DHIFrame
 * @desc 1、iframe父页面发送消息到子页面 2、iframe父页面接收子页面消息
 * @author zhangyibo02
 */

const MESSAGE_TYPE = {
    TEXT_RENDER: 'TEXT_RENDER',
    TEXT_QUERY: 'TEXT_QUERY'
};

export default {
    /**
     * 注册接收数据方法
     * * @param {(this: Window, ev: MessageEvent<any>) => any} callback 方法实现
     */
    registerMessageReceived(callback: (this: Window, ev: MessageEvent<any>) => void) {
        if (typeof window.addEventListener !== 'undefined') {
            window.addEventListener('message', callback, false);
        }
    },

    /**
     * 移除接收数据方法
     * @param {(this: Window, ev: MessageEvent<any>) => any} callback 方法实现
     */
    removeMessageReceived(callback: (this: Window, ev: MessageEvent<any>) => void) {
        if (typeof window.addEventListener !== 'undefined') {
            window.removeEventListener('message', callback, false);
        }
    },

    /**
     * 发送消息到iframe - 基础方法
     * @param {string} type 消息类型
     * @param {any} content 消息内容
     */
    sendMessageToIframe(type: string, content: any) {
        // 业务里面的iframe
        const iframeEle: any | null = document.getElementById('digital-human-iframe') as HTMLIFrameElement;
        if (type && iframeEle !== null) {
            iframeEle.contentWindow.postMessage({type, content}, '*');
        }
    },

    /**
     * 发送 command 消息到 iframe
     * @param {any} message 消息
     */
    sendCommand(command: any) {
        this.sendMessageToIframe('command', command);
    },

    /**
     * 发送 message 消息到 iframe
     * @param {any} message 消息
     */
    sendMessage(message: any) {
        this.sendMessageToIframe('message', message);
    },

    /**
     * 发送 audioData 音频数据 消息到 iframe
     * @param {string} message 消息
     */
    sendAudioData(audioData: any) {
        this.sendMessageToIframe('audioData', audioData);
    },

    /**
     * 文本驱动数字人
     * @param {any} message 消息
     */
    textRender(message: any) {
        this.sendMessage({
            action: MESSAGE_TYPE.TEXT_RENDER,
            body: message
        });
    },

    /**
     * 发起对话提问
     * @param {any} message 消息
     */
    textQuery(message: any) {
        this.sendMessage({
            action: MESSAGE_TYPE.TEXT_QUERY,
            body: message
        });
    },

    /**
     * 静音
     * @param {boolean} mute
     */
    mute(mute: boolean) {
        this.sendCommand({
            subType: 'mute',
            subContent: mute
        });
    },

    /**
     * 静音audio元素声音
     * @param {boolean} mute
     */
    muteAudio(mute: boolean) {
        this.sendCommand({
            subType: 'muteAudio',
            subContent: mute
        });
    },

    /**
     * 远端静音
     * @param {boolean} mute
     */
    muteRemoteAudio(mute: boolean) {
        this.sendCommand({
            subType: 'muteRemoteAudio',
            subContent: mute
        });
    },

    /**
     * 播放
     * @param {boolean} mute
     */
    playVideo(play: boolean) {
        this.sendCommand({
            subType: 'playVideo',
            subContent: play
        });
    }
};